==> jc-1.4.0.tar.gz: javax/print/attribute/standard/MediaSize.h <==
// public class javax.print.attribute.standard.MediaSize

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bd6a0e5e38ab5fce javax_print_attribute_Size2DSyntax
// @dep_class 3c25636770daec84 javax_print_attribute_standard_MediaSize

// header file dependencies
// @dep_header javax_print_attribute_Size2DSyntax

#include "javax/print/attribute/Size2DSyntax.h"

#ifndef _JC_javax_print_attribute_standard_MediaSize_H_
#define _JC_javax_print_attribute_standard_MediaSize_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ArrayList$object;
struct _jc_javax_print_attribute_standard_MediaSize$object;
struct _jc_javax_print_attribute_standard_MediaSizeName$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_MediaSize$sub_refs	_jc_javax_print_attribute_standard_MediaSize$sub_refs;
typedef struct _jc_javax_print_attribute_standard_MediaSize$sub_nonrefs	_jc_javax_print_attribute_standard_MediaSize$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_MediaSize$refs	_jc_javax_print_attribute_standard_MediaSize$refs;
typedef struct _jc_javax_print_attribute_standard_MediaSize$nonrefs	_jc_javax_print_attribute_standard_MediaSize$nonrefs;
typedef struct _jc_javax_print_attribute_standard_MediaSize$object	_jc_javax_print_attribute_standard_MediaSize$object;

typedef struct _jc_javax_print_attribute_standard_MediaSize$fields_struct	_jc_javax_print_attribute_standard_MediaSize$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_MediaSize$vmethods	_jc_javax_print_attribute_standard_MediaSize$vmethods;
typedef const struct _jc_javax_print_attribute_standard_MediaSize$vtable	_jc_javax_print_attribute_standard_MediaSize$vtable;
typedef const struct _jc_javax_print_attribute_standard_MediaSize$vtype	_jc_javax_print_attribute_standard_MediaSize$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_MediaSize$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24MediaSize;
	struct _jc_java_util_ArrayList$object	*mediaCache;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_MediaSize$fields_struct _jc_javax_print_attribute_standard_MediaSize$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_MediaSize$method$_init$657c0f391c1e5786(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *, jfloat, jfloat, jint);
extern void _jc_javax_print_attribute_standard_MediaSize$method$_init$d1594277c589782a(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *, jfloat, jfloat, jint, struct _jc_javax_print_attribute_standard_MediaSizeName$object *);
extern void _jc_javax_print_attribute_standard_MediaSize$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *, jint, jint, jint);
extern void _jc_javax_print_attribute_standard_MediaSize$method$_init$f1541faf048d0e81(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *, jint, jint, jint, struct _jc_javax_print_attribute_standard_MediaSizeName$object *);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_MediaSize$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *);
extern struct _jc_javax_print_attribute_standard_MediaSizeName$object *_jc_javax_print_attribute_standard_MediaSize$method$getMediaSizeName$156f9a607bb1f2f5(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_MediaSize$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_MediaSize$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_MediaSize$method_info$getMediaSizeName$156f9a607bb1f2f5;
extern _jc_method _jc_javax_print_attribute_standard_MediaSize$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_MediaSize$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_MediaSize$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_javax_print_attribute_standard_MediaSize$object *_jc_javax_print_attribute_standard_MediaSize$method$getMediaSizeForName$3ab7358eaf083ad2(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSizeName$object *);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_MediaSize$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *);
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*(*getMediaSizeName$156f9a607bb1f2f5)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_MediaSize$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_Size2DSyntax$vmethods	javax_print_attribute_Size2DSyntax;
	_jc_javax_print_attribute_standard_MediaSize$vmethods	javax_print_attribute_standard_MediaSize;
};

// Vtype
struct _jc_javax_print_attribute_standard_MediaSize$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_MediaSize$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_MediaSize$sub_refs {
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*media;
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_MediaSize$refs {
    _jc_javax_print_attribute_standard_MediaSize$sub_refs	javax_print_attribute_standard_MediaSize;
    _jc_javax_print_attribute_Size2DSyntax$sub_refs	javax_print_attribute_Size2DSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_MediaSize$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_MediaSize$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_Size2DSyntax$sub_nonrefs	javax_print_attribute_Size2DSyntax;
    _jc_javax_print_attribute_standard_MediaSize$sub_nonrefs	javax_print_attribute_standard_MediaSize;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_MediaSize$object {
	_jc_javax_print_attribute_standard_MediaSize$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_MediaSize$vtype	*vtype;
	_jc_javax_print_attribute_standard_MediaSize$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_MediaSize$vtype _jc_javax_print_attribute_standard_MediaSize$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_MediaSize, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_MediaSize$class_object;

#endif	/* _JC_javax_print_attribute_standard_MediaSize_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/MediaSize.h <==
// public class javax.print.attribute.standard.MediaSize

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bd6a0e5e38ab5fce javax_print_attribute_Size2DSyntax
// @dep_class 3c25636770daec84 javax_print_attribute_standard_MediaSize

// header file dependencies
// @dep_header javax_print_attribute_Size2DSyntax

#include "javax/print/attribute/Size2DSyntax.h"

#ifndef _JC_javax_print_attribute_standard_MediaSize_H_
#define _JC_javax_print_attribute_standard_MediaSize_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ArrayList$object;
struct _jc_javax_print_attribute_standard_MediaSize$object;
struct _jc_javax_print_attribute_standard_MediaSizeName$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_MediaSize$sub_refs	_jc_javax_print_attribute_standard_MediaSize$sub_refs;
typedef struct _jc_javax_print_attribute_standard_MediaSize$sub_nonrefs	_jc_javax_print_attribute_standard_MediaSize$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_MediaSize$refs	_jc_javax_print_attribute_standard_MediaSize$refs;
typedef struct _jc_javax_print_attribute_standard_MediaSize$nonrefs	_jc_javax_print_attribute_standard_MediaSize$nonrefs;
typedef struct _jc_javax_print_attribute_standard_MediaSize$object	_jc_javax_print_attribute_standard_MediaSize$object;

typedef struct _jc_javax_print_attribute_standard_MediaSize$fields_struct	_jc_javax_print_attribute_standard_MediaSize$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_MediaSize$vmethods	_jc_javax_print_attribute_standard_MediaSize$vmethods;
typedef const struct _jc_javax_print_attribute_standard_MediaSize$vtable	_jc_javax_print_attribute_standard_MediaSize$vtable;
typedef const struct _jc_javax_print_attribute_standard_MediaSize$vtype	_jc_javax_print_attribute_standard_MediaSize$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_MediaSize$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24MediaSize;
	struct _jc_java_util_ArrayList$object	*mediaCache;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_MediaSize$fields_struct _jc_javax_print_attribute_standard_MediaSize$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_MediaSize$method$_init$657c0f391c1e5786(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *, jfloat, jfloat, jint) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_standard_MediaSize$method$_init$d1594277c589782a(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *, jfloat, jfloat, jint, struct _jc_javax_print_attribute_standard_MediaSizeName$object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_standard_MediaSize$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_standard_MediaSize$method$_init$f1541faf048d0e81(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *, jint, jint, jint, struct _jc_javax_print_attribute_standard_MediaSizeName$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_MediaSize$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_print_attribute_standard_MediaSizeName$object *_jc_javax_print_attribute_standard_MediaSize$method$getMediaSizeName$156f9a607bb1f2f5(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_MediaSize$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_MediaSize$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_MediaSize$method_info$getMediaSizeName$156f9a607bb1f2f5;
extern _jc_method _jc_javax_print_attribute_standard_MediaSize$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_MediaSize$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_MediaSize$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_javax_print_attribute_standard_MediaSize$object *_jc_javax_print_attribute_standard_MediaSize$method$getMediaSizeForName$3ab7358eaf083ad2(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSizeName$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_MediaSize$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *) _JC_JCNI_ATTR;
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*(*getMediaSizeName$156f9a607bb1f2f5)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_MediaSize$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_MediaSize$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_Size2DSyntax$vmethods	javax_print_attribute_Size2DSyntax;
	_jc_javax_print_attribute_standard_MediaSize$vmethods	javax_print_attribute_standard_MediaSize;
};

// Vtype
struct _jc_javax_print_attribute_standard_MediaSize$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_MediaSize$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_MediaSize$sub_refs {
	struct _jc_javax_print_attribute_standard_MediaSizeName$object	*media;
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_MediaSize$refs {
    _jc_javax_print_attribute_standard_MediaSize$sub_refs	javax_print_attribute_standard_MediaSize;
    _jc_javax_print_attribute_Size2DSyntax$sub_refs	javax_print_attribute_Size2DSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_MediaSize$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_MediaSize$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_Size2DSyntax$sub_nonrefs	javax_print_attribute_Size2DSyntax;
    _jc_javax_print_attribute_standard_MediaSize$sub_nonrefs	javax_print_attribute_standard_MediaSize;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_MediaSize$object {
	_jc_javax_print_attribute_standard_MediaSize$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_MediaSize$vtype	*vtype;
	_jc_javax_print_attribute_standard_MediaSize$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_MediaSize$vtype _jc_javax_print_attribute_standard_MediaSize$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_MediaSize, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_MediaSize$class_object;

#endif	/* _JC_javax_print_attribute_standard_MediaSize_H_ */
